"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.access.access_pb2
import yandex.cloud.operation.operation_pb2
import yandex.cloud.ydb.v1.backup_pb2
import yandex.cloud.ydb.v1.backup_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class BackupServiceStub:
    """A set of methods for managing backups."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ydb.v1.backup_service_pb2.GetBackupRequest,
        yandex.cloud.ydb.v1.backup_pb2.Backup,
    ]
    """Returns the specified backup."""

    ListPaths: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ydb.v1.backup_service_pb2.ListPathsRequest,
        yandex.cloud.ydb.v1.backup_service_pb2.ListPathsResponse,
    ]

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ydb.v1.backup_service_pb2.ListBackupsRequest,
        yandex.cloud.ydb.v1.backup_service_pb2.ListBackupsResponse,
    ]
    """Retrieves a list of backups."""

    ListAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]

    SetAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]

    UpdateAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ydb.v1.backup_service_pb2.DeleteBackupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified backup."""

class BackupServiceAsyncStub:
    """A set of methods for managing backups."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ydb.v1.backup_service_pb2.GetBackupRequest,
        yandex.cloud.ydb.v1.backup_pb2.Backup,
    ]
    """Returns the specified backup."""

    ListPaths: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ydb.v1.backup_service_pb2.ListPathsRequest,
        yandex.cloud.ydb.v1.backup_service_pb2.ListPathsResponse,
    ]

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ydb.v1.backup_service_pb2.ListBackupsRequest,
        yandex.cloud.ydb.v1.backup_service_pb2.ListBackupsResponse,
    ]
    """Retrieves a list of backups."""

    ListAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]

    SetAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]

    UpdateAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ydb.v1.backup_service_pb2.DeleteBackupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified backup."""

class BackupServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing backups."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.ydb.v1.backup_service_pb2.GetBackupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ydb.v1.backup_pb2.Backup, collections.abc.Awaitable[yandex.cloud.ydb.v1.backup_pb2.Backup]]:
        """Returns the specified backup."""

    @abc.abstractmethod
    def ListPaths(
        self,
        request: yandex.cloud.ydb.v1.backup_service_pb2.ListPathsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ydb.v1.backup_service_pb2.ListPathsResponse, collections.abc.Awaitable[yandex.cloud.ydb.v1.backup_service_pb2.ListPathsResponse]]: ...

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.ydb.v1.backup_service_pb2.ListBackupsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ydb.v1.backup_service_pb2.ListBackupsResponse, collections.abc.Awaitable[yandex.cloud.ydb.v1.backup_service_pb2.ListBackupsResponse]]:
        """Retrieves a list of backups."""

    @abc.abstractmethod
    def ListAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.access.access_pb2.ListAccessBindingsResponse, collections.abc.Awaitable[yandex.cloud.access.access_pb2.ListAccessBindingsResponse]]: ...

    @abc.abstractmethod
    def SetAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]: ...

    @abc.abstractmethod
    def UpdateAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]: ...

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.ydb.v1.backup_service_pb2.DeleteBackupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified backup."""

def add_BackupServiceServicer_to_server(servicer: BackupServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
